@@ -13,7 +13,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(encode_json);
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 our %theme = (
     start_quote         => BOLD . BRIGHT_GREEN,
@@ -220,7 +220,7 @@ JSON::Color - Encode to colored JSON
 
 =head1 VERSION
 
-This document describes version 0.11 of JSON::Color (from Perl distribution JSON-Color), released on 2015-12-23.
+This document describes version 0.12 of JSON::Color (from Perl distribution JSON-Color), released on 2016-08-23.
 
 =head1 SYNOPSIS
 
@@ -279,12 +279,20 @@ Use L<JSON>.
 
 Use L<Data::Clean::JSON>.
 
-=head1 SEE ALSO
+=head2 Why do numbers become strings?
 
-To colorize with HTML, you can try L<Syntax::Highlight::JSON>.
+Example:
 
-L<Syntax::SourceHighlight> can also colorize JSON/JavaScript to HTML or ANSI
-escape. It requires the GNU Source-highlight library.
+ % perl -MJSON::Color=encode_json -E'say encode_json([1, "1"])'
+ ["1","1"]
+
+To detect whether a scalar is a number (e.g. differentiate between "1" and 1),
+the XS module L<Scalar::Util::LooksLikeNumber> is used. This is set as an
+optional prerequisite, so you'll need to install it separately. After the
+prerequisite is installed:
+
+ % perl -MJSON::Color=encode_json -E'say encode_json([1, "1"])'
+ [1,"1"]
 
 =head1 HOMEPAGE
 
@@ -302,13 +310,20 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+To colorize with HTML, you can try L<Syntax::Highlight::JSON>.
+
+L<Syntax::SourceHighlight> can also colorize JSON/JavaScript to HTML or ANSI
+escape. It requires the GNU Source-highlight library.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
